<?php

namespace Litecms\OurServices\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\OurServices\Http\Requests\OurServiceRequest;
use Litecms\OurServices\Interfaces\OurServiceRepositoryInterface;
use Litecms\OurServices\Models\OurService;

/**
 * Resource controller class for our_service.
 */
class OurServiceResourceController extends BaseController
{

    /**
     * Initialize our_service resource controller.
     *
     * @param type OurServiceRepositoryInterface $our_service
     *
     * @return null
     */
    public function __construct(OurServiceRepositoryInterface $our_service)
    {
        parent::__construct();
        $this->repository = $our_service;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\OurServices\Repositories\Criteria\OurServiceResourceCriteria::class);
    }

    /**
     * Display a list of our_service.
     *
     * @return Response
     */
    public function index(OurServiceRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\OurServices\Repositories\Presenter\OurServicePresenter::class)
                ->$function();
        }

        $our_services = $this->repository->paginate();

        return $this->response->title(trans('our_services::our_service.names'))
            ->view('our_services::our_service.index', true)
            ->data(compact('our_services'))
            ->output();
    }

    /**
     * Display our_service.
     *
     * @param Request $request
     * @param Model   $our_service
     *
     * @return Response
     */
    public function show(OurServiceRequest $request, OurService $our_service)
    {

        if ($our_service->exists) {
            $view = 'our_services::our_service.show';
        } else {
            $view = 'our_services::our_service.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('our_services::our_service.name'))
            ->data(compact('our_service'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new our_service.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OurServiceRequest $request)
    {

        $our_service = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('our_services::our_service.name')) 
            ->view('our_services::our_service.create', true) 
            ->data(compact('our_service'))
            ->output();
    }

    /**
     * Create new our_service.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OurServiceRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $our_service                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('our_services::our_service.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('our_services/our_service/' . $our_service->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/our_services/our_service'))
                ->redirect();
        }

    }

    /**
     * Show our_service for editing.
     *
     * @param Request $request
     * @param Model   $our_service
     *
     * @return Response
     */
    public function edit(OurServiceRequest $request, OurService $our_service)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('our_services::our_service.name'))
            ->view('our_services::our_service.edit', true)
            ->data(compact('our_service'))
            ->output();
    }

    /**
     * Update the our_service.
     *
     * @param Request $request
     * @param Model   $our_service
     *
     * @return Response
     */
    public function update(OurServiceRequest $request, OurService $our_service)
    {
        try {
            $attributes = $request->all();

            $our_service->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('our_services::our_service.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('our_services/our_service/' . $our_service->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('our_services/our_service/' . $our_service->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the our_service.
     *
     * @param Model   $our_service
     *
     * @return Response
     */
    public function destroy(OurServiceRequest $request, OurService $our_service)
    {
        try {

            $our_service->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('our_services::our_service.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('our_services/our_service/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('our_services/our_service/' . $our_service->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple our_service.
     *
     * @param Model   $our_service
     *
     * @return Response
     */
    public function delete(OurServiceRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('our_services::our_service.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('our_services/our_service'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/our_services/our_service'))
                ->redirect();
        }

    }

    /**
     * Restore deleted our_services.
     *
     * @param Model   $our_service
     *
     * @return Response
     */
    public function restore(OurServiceRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('our_services::our_service.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/our_services/our_service'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/our_services/our_service/'))
                ->redirect();
        }

    }

}
